@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 templates_path = ["_templates"]
 source_suffix = ".rst"
 master_doc = "index"
@@ -15,6 +13,5 @@ todo_include_todos = False
 html_theme = "alabaster"
 htmlhelp_basename = "pyexampledoc"
 extensions = ["sphinx.ext.autodoc", "autoapi.extension"]
-autoapi_type = "python"
 autoapi_dirs = ["example"]
 autoapi_file_pattern = "*.py"
