@@ -1,7 +1,12 @@
+"""
+This heading will be removed
+============================
+"""
+
 from .subpackage import public_chain
 from .subpackage.submodule import public_multiple_imports
 
 
-def module_level_method(foo, bar):
+def module_level_function(foo, bar):
     """A module level method"""
     pass
