@@ -3,6 +3,6 @@ from .submodule import _private_made_public as now_public_function
 from .submodule import public_multiple_imports
 
 
-def module_level_method(foo, bar):
+def module_level_function(foo, bar):
     """A module level method"""
     pass
