@@ -67,9 +67,7 @@ class TestAstroidUtils:
         {}
         class ThisClass({}): #@
             pass
-        """.format(
-            import_, basename
-        )
+        """.format(import_, basename)
         node = astroid.extract_node(source)
         basenames = _astroid_utils.resolve_qualname(node.bases[0], node.basenames[0])
         assert basenames == expected
@@ -82,9 +80,7 @@ class TestAstroidUtils:
         {}
         class ThisClass({}): #@
             pass
-        """.format(
-            import_, basename
-        )
+        """.format(import_, basename)
         node = astroid.extract_node(source)
         basenames = _astroid_utils.resolve_qualname(node.bases[0], node.basenames[0])
         assert basenames == expected
@@ -108,6 +104,8 @@ class TestAstroidUtils:
     def test_can_get_assign_values(self, source, expected):
         node = astroid.extract_node(source)
         value = _astroid_utils.get_assign_value(node)
+        if value:
+            value = (value[0], _astroid_utils.get_const_value(value[1]))
         assert value == expected
 
     @pytest.mark.parametrize(
@@ -163,9 +161,7 @@ class TestAstroidUtils:
             """
             def func({}) -> str: #@
                 pass
-        """.format(
-                signature
-            )
+        """.format(signature)
         )
 
         annotations = _astroid_utils.get_args_info(node.args)
@@ -227,9 +223,7 @@ class TestAstroidUtils:
             """
             def func({}) -> str: #@
                 pass
-        """.format(
-                signature
-            )
+        """.format(signature)
         )
 
         args_info = _astroid_utils.get_args_info(node.args)
